Add copy_coherency test

Test cache managemenent and synchronization between kernel and copy commands
in separate queues.
This commit is contained in:
Ben Sander
2017-10-07 07:46:40 -07:00
parent 89ad18584d
commit cb613bb6a8
2 changed files with 404 additions and 0 deletions
@@ -0,0 +1,13 @@
#include <hip/hip_runtime.h>
extern "C" __global__ void
memcpyIntKernel(hipLaunchParm lp, int *dst, const int * src, size_t numElements)
{
int gid = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x);
int stride = hipBlockDim_x * hipGridDim_x ;
for (size_t i= gid; i< numElements; i+=stride){
dst[i] = src[i];
}
};